# MCP-researcher Server

Your own research assistant inside of Cline! Utilizes Perplexity's Sonar API to get docs, create up-to-date API routes, check deprecated code, and perform deep research while you create features with Cline.

Includes Chain of Thought Reasoning and local chat history through SQLite.


## Tools

### 1. [Search](https://github.com/DaInfernalCoder/researcher-mcp/blob/main/examples/search.md)
Performs general search queries to get comprehensive information on any topic. The example shows how to use different detail levels (brief, normal, detailed) to get tailored responses.

### 2. [Get Documentation](https://github.com/DaInfernalCoder/researcher-mcp/blob/main/examples/find-apis.md)
Retrieves documentation and usage examples for specific technologies, libraries, or APIs. The example demonstrates getting comprehensive documentation for React hooks, including best practices and common pitfalls.

### 3. [Find APIs](https://github.com/DaInfernalCoder/researcher-mcp/blob/main/examples/find-apis.md)
Discovers and evaluates APIs that could be integrated into a project. The example shows finding payment processing APIs with detailed analysis of features, pricing, and integration complexity.

### 4. [Check Deprecated Code](https://github.com/DaInfernalCoder/researcher-mcp/blob/main/examples/check-deprecated-code.md)
Analyzes code for deprecated features or patterns, providing migration guidance. The example demonstrates checking React class components and lifecycle methods for modern alternatives.

### 5. [Deep Research](https://github.com/DaInfernalCoder/researcher-mcp/blob/main/examples/deep-research.md)
Conducts comprehensive, in-depth research on complex topics using Perplexity's sonar-deep-research model. Provides thorough analysis with background, key concepts, current state of knowledge, different perspectives, recent developments, practical applications, challenges, future directions, expert opinions, and references.

## Setup and Usage

1. **Prerequisites**
   - Install Node.js if not already installed (from [nodejs.org](https://nodejs.org))
   - Get a Perplexity API key from [https://www.perplexity.ai/settings/api](https://www.perplexity.ai/settings/api)

2. **Clone and Setup**
```bash
# Clone the repository
git clone https://github.com/DaInfernalCoder/researcher-mcp perplexity-server
cd perplexity-server

# Install dependencies
npm install

# Build the server
npm run build
```

3. **Configure MCP Settings**

Create or update your MCP settings file in the appropriate location:

- macOS: `~/Library/Application Support/Cursor/User/globalStorage/saoudrizwan.claude-dev/settings/cline_mcp_settings.json`
- Windows: `%APPDATA%\Cursor\User\globalStorage\saoudrizwan.claude-dev\settings\cline_mcp_settings.json`
- Linux: `~/.config/Cursor/User/globalStorage/saoudrizwan.claude-dev/settings/cline_mcp_settings.json`

For Claude Desktop, the config file is located at:
- macOS: `~/Library/Application Support/Claude/claude_desktop_config.json`
- Windows: `%APPDATA%/Claude/claude_desktop_config.json`

Add the following configuration:

```json
{
  "mcpServers": {
    "perplexity-server": {
      "command": "node",
      "args": [
        "/absolute/path/to/perplexity-server/build/index.js"
      ],
      "env": {
        "PERPLEXITY_API_KEY": "YOUR_API_KEY_HERE"
      },
      "disabled": false,
      "autoApprove": [
        "search",
        "get_documentation",
        "find_apis",
        "check_deprecated_code",
        "deep_research"
      ]
    }
  }
}
```

Make sure to:
- Replace `/absolute/path/to` with the actual path where you cloned the repository
- Replace `YOUR_API_KEY_HERE` with your Perplexity API key

4. **Run the Server**
```bash
# Start the server
npm start
```

## Deep Research Example

Here's an example of using the new deep research tool:

```javascript
// Example of using the deep_research tool
const result = await use_mcp_tool({
  server_name: "perplexity-ask",
  tool_name: "deep_research",
  arguments: {
    query: "The impact of quantum computing on cryptography",
    focus_areas: [
      "Post-quantum cryptographic algorithms",
      "Timeline for quantum threats to current encryption",
      "Practical mitigation strategies for organizations"
    ]
  }
});

console.log(result);
```

This will provide a comprehensive analysis of quantum computing's impact on cryptography, with special focus on the specified areas, using Perplexity's sonar-deep-research model for enhanced depth and accuracy.
