# Product Context

## Purpose
The Perplexity Server is an MCP (Model Context Protocol) server that integrates with Perplexity AI's API to provide research and documentation capabilities to AI assistants like Cline. It serves as a research assistant that can search for information, retrieve documentation, find APIs, and check for deprecated code.

## Problems Solved
1. **Information Access**: Provides up-to-date information from the web through Perplexity's search capabilities
2. **Documentation Retrieval**: Quickly fetches documentation for technologies, libraries, and APIs
3. **API Discovery**: Helps find and evaluate APIs that could be integrated into projects
4. **Code Maintenance**: Identifies deprecated code patterns and suggests modern alternatives
5. **Persistent Conversations**: Maintains chat history locally through SQLite

## How It Works
The server connects to Perplexity's API using an API key and exposes several tools through the MCP protocol:

1. **chat_perplexity**: Maintains ongoing conversations with Perplexity AI with full history context
2. **search**: Performs general search queries with adjustable detail levels
3. **get_documentation**: Retrieves documentation and usage examples for specific technologies
4. **find_apis**: Discovers and evaluates APIs for potential integration
5. **check_deprecated_code**: Analyzes code for deprecated features and suggests alternatives
6. **deep_research**: Conducts comprehensive, in-depth research on complex topics using the sonar-deep-research model
7. **call_any_model**: Provides flexibility to call different AI models through Perplexity

The server uses SQLite to maintain chat history locally, allowing for persistent conversations across sessions.

## Distribution
The server is packaged as an NPM package that can be easily installed and run using NPX:

```bash
npx -y @modelcontextprotocol/server-perplexity-ask
```

This allows for easy installation and updates without requiring manual cloning and building of the repository.
