# System Patterns

## Architecture
The Perplexity Server follows a standard MCP server architecture:

1. **Server Initialization**
   - Creates an MCP server instance
   - Sets up API client with authentication
   - Initializes SQLite database for chat history
   - Registers tool handlers

2. **Tool Registration**
   - Defines available tools with descriptions and input schemas
   - Implements handlers for each tool

3. **Database Management**
   - Uses SQLite for local persistence
   - Maintains chat history across sessions
   - Stores messages with chat IDs for organization

4. **API Integration**
   - Communicates with Perplexity API
   - Uses axios for HTTP requests
   - Handles authentication via API key
   - Manages error handling and response parsing

## Key Technical Decisions
1. **Local Storage with SQLite**
   - Provides persistence without external dependencies
   - Enables chat history across sessions
   - Lightweight and embedded database

2. **ES Modules**
   - Uses modern JavaScript module system
   - Configured with "type": "module" in package.json

3. **TypeScript**
   - Provides type safety and better developer experience
   - Compiled to JavaScript for execution

4. **Direct Node.js Execution**
   - Runs directly with Node.js
   - No installation required
   - Dependencies managed locally

5. **Error Handling**
   - Converts API errors to MCP errors
   - Provides meaningful error messages
   - Graceful shutdown on SIGINT

6. **Local Development**
   - Clone repository and install dependencies
   - Build TypeScript code
   - Run directly with Node.js

7. **Model Selection**
   - Uses sonar-reasoning-pro for general queries
   - Uses sonar-deep-research for comprehensive research
   - Flexible model selection through call_any_model tool

## Communication Patterns
1. **MCP Protocol**
   - Communicates via stdio transport
   - Follows MCP request/response format
   - Defines tools with input schemas

2. **API Communication**
   - RESTful API calls to Perplexity
   - JSON request/response format
   - Bearer token authentication
