# Technical Context

## Technologies Used

### Core Technologies
- **Node.js**: Runtime environment for the server
- **TypeScript**: Programming language for type safety
- **MCP SDK**: Model Context Protocol SDK for server implementation
- **SQLite**: Embedded database for chat history storage

### Dependencies
- **@modelcontextprotocol/sdk (0.6.0)**: MCP server implementation
- **axios (^1.7.9)**: HTTP client for API requests
- **better-sqlite3 (^11.8.1)**: SQLite database driver

### Development Dependencies
- **@types/better-sqlite3 (^7.6.12)**: TypeScript types for better-sqlite3
- **@types/node (^20.11.24)**: TypeScript types for Node.js
- **typescript (^5.3.3)**: TypeScript compiler

## Development Setup
1. **Build Process**:
   - TypeScript compilation with `tsc`
   - Watch mode available with `tsc --watch`
   - Direct execution with `npm start`

2. **Testing**:
   - Type checking with `tsc --noEmit`
   - MCP Inspector for manual testing

3. **Environment Variables**:
   - `PERPLEXITY_API_KEY`: Required for API authentication

## Technical Constraints
1. **API Limitations**:
   - Requires valid Perplexity API key
   - Subject to Perplexity API rate limits and quotas
   - Dependent on Perplexity API availability

2. **Runtime Requirements**:
   - Node.js runtime environment
   - Local dependencies (installed via npm install)
   - File system access for SQLite database

3. **Integration Constraints**:
   - Follows MCP protocol for communication
   - Requires MCP-compatible client
   - Communication via stdio transport

## Local Setup
1. **Repository Setup**:
   - Clone the repository
   - Run `npm install` to install dependencies
   - Build with `npm run build`
   - Start with `npm start`

2. **Configuration**:
   - Set PERPLEXITY_API_KEY environment variable
   - SQLite database created automatically
   - Example usage provided in README.md

3. **Usage**:
   - Run directly with Node.js
   - No global installation needed
   - Configure in MCP settings as local server
